// *** SciGui work figure handling
// *** by G. Casonato - Marzo 2007

function loadFigure(fd, hfig_wk)
  disp('Load Main Figure...');
  
  // legge dati da file
  str = mgetl(fd, 1); // position
  pos = strindex(str, '[');
  str1 = strsplit(str, pos);
  [px, py, wd, hg] = sscanf(str1(2), '%d %d %d %d]');

  // aggiorna finestra
  set(hfig_wk, 'position', [px py wd hg] );
endfunction

function saveFigure (fd, hfig_wk)
  disp('Save Figure...');
  
  pos = get(hfig_wk, 'position');
  pos = evstr(pos);
  mfprintf(fd, '// MAIN GUI\n');
  mfprintf(fd, 'hfig = figure(1, ''position'', [%d %d %d %d]);\n\n', ...
    pos(1), pos(2), pos(3), pos(4));
endfunction

function hfig_wk = editFigure (hmode, hfig, hfig_wk)
  disp('Edit Figure...');

  // hmode definisce modalit:
  // - new:  crea nuova oggetto con ID <hobj>
  // - edit: modifica oggetto esistente <hobj>

  // legge posizione/nome
  if hmode == 'edit' then
    // edit: legge valori correnti
    objpos = get(hfig_wk, 'position');

    // legge posizione/nome
    lbl = ['position (x, y): '; 'size (width, height): '];
    def = [string(objpos(1))+' '+string(objpos(2)); ...
           string(objpos(3))+' '+string(objpos(4))];
    objdata = x_mdialog('enter object data', lbl, def);
    objpos = evstr(objdata(1 : 2));
    px = objpos(1,1);
    py = objpos(1,2);
    wd = objpos(2,1);
    hg = objpos(2,2);

    // modifica parametri oggetto   
    set(hfig_wk, 'position', [px py wd hg]);

    // rimuove griglia, se attiva
    if get(hgr(1), 'ForegroundColor') == name2rgb('black') then
      showGrid(hfig_wk);
    end
  else
    // new: imposta valori di default
    objpos = [100 170 400 300];
    px = objpos(1);
    py = objpos(2);
    wd = objpos(3);
    hg = objpos(4);

    // crea finestra di lavoro con le dimensioni specificate
    hfig_wk = figure(hfig_wk, 'position', [px py wd hg]);
  end
  
  // (ri)disegna griglia
  drawGrid(hfig_wk);
endfunction

function showGrid (hfig_wk);
  disp('Show Grid...');

  global hgr;

  if get(hgr(1), 'ForegroundColor') == name2rgb('black') then
    doRemove = %T;
  else
    doRemove = %F;
  end

  // attiva/disattiva griglia
  for i = 1 : size(hgr, 1)
    if doRemove == %T  then
        // rimuovi griglia
        grcol = name2rgb('lightgray')
    else
        // disegna griglia
        grcol = name2rgb('black')
    end 
    if get(hgr(i), 'style') == 'text' then
      set(hgr(i), 'ForegroundColor', grcol);
    else
      set(hgr(i), 'BackgroundColor', grcol);    
    end
  end
endfunction

function drawGrid(hfig_wk)
  global hgr;
  hgr = [];
  
  // disegna griglia 
  grcol = name2rgb('black');
  pos = get(hfig_wk, 'position');
  wd = pos(3);
  hg = pos(4);
  
  // righe
  sty = 50;
  for y = sty : sty : hg
    h = uicontrol(hfig_wk, 'style', 'text', ...
      'tag', 'GridLblY'+string(y), ...
      'Horizontalalignment', 'left', ...
      'ForegroundColor ', grcol, ...
      'fontsize', 8, ...
      'string', string(y), ...
      'position', [0 y 20 10]); 
    hgr = [hgr; [h]];
    h = uicontrol(hfig_wk, 'style', 'pushbutton', ...
      'tag', 'GridRowY'+string(y), ...
      'ForegroundColor ', grcol, ...
      'position', [20 y+5 wd-25 1]); 
    hgr = [hgr; [h]];
  end

  // colonne
  stx = 50;
  for x = stx : stx : wd
    h = uicontrol(hfig_wk, 'style', 'text', ...
      'tag', 'GridLblX'+string(x), ...
      'Horizontalalignment', 'left', ...
      'ForegroundColor ', grcol, ...
      'fontsize', 8, ...
      'string', string(x), ...
      'position', [x 0 20 10]); 
    hgr = [hgr; [h]];
    h = uicontrol(hfig_wk, 'style', 'pushbutton', ...
      'tag', 'GridRowX'+string(x), ...
      'ForegroundColor ', grcol, ...
      'position', [x+5 15 1 hg-25]); 
    hgr = [hgr; [h]];
  end
endfunction

